🛠️ Welcome to Stouputils Documentation — stouputils 1.0.18 documentation

# 🛠️ Welcome to Stouputils Documentation

## 📚 Overview

Stouputils is a collection of utility modules designed to simplify and enhance the development process. It includes a range of tools for tasks such as execution of doctests, display utilities, decorators, as well as context managers.

## 🚀 Project Structure

    stouputils/
    ├── continuous_delivery/
    │   ├── github.py             # 📦 GitHub utilities that are very specific (upload_to_github)
    │   └── ...
    │
    ├── print.py                  # 🖨️ Display utilities
    ├── io.py                     # 💻 I/O utilities (for file management, json, etc.)
    ├── decorators.py             # 🎯 Decorators (silent, measure_time, error_handler, simple_cache, deprecated)
    ├── ctx.py                    # 🚫 Context managers (Muffle)
    ├── archive.py                # 📦 Archive utilities (zip, unzip)
    ├── parallel.py               # 🧑‍🤝‍🧑 Parallel processing (multiprocessing, multithreading)
    ├── collections.py            # 🧰 Collection utilities (unique_list)
    ├── all_doctests.py           # ✅ Execution of all doctests of all modules for a given path
    ├── backup.py                 # 📦 Backup utilities (create_delta_backup, consolidate_backups, backup_cli)
    └── ...

## 📖 Module Documentation

Contents:

- stouputils package
  - Subpackages
    - stouputils.continuous_delivery package
      - Submodules
        - stouputils.continuous_delivery.cd_utils module
          - `load_credentials()`
          - `handle_response()`
        - stouputils.continuous_delivery.github module
          - `validate_credentials()`
          - `validate_config()`
          - `handle_existing_tag()`
          - `delete_existing_release()`
          - `delete_existing_tag()`
          - `clean_version()`
          - `version_to_float()`
          - `get_latest_tag()`
          - `get_commits_since_tag()`
          - `generate_changelog()`
          - `create_tag()`
          - `create_release()`
          - `upload_assets()`
          - `upload_to_github()`
    - stouputils.dont_look namespace
      - Submodules
        - stouputils.dont_look.zip_file_override module
  - Submodules
    - stouputils.all_doctests module
      - `launch_tests()`
    - stouputils.archive module
      - `make_archive()`
      - `repair_zip_file()`
    - stouputils.backup module
      - `get_file_hash()`
      - `extract_hash_from_zipinfo()`
      - `get_all_previous_backups()`
      - `is_file_in_any_previous_backup()`
      - `create_delta_backup()`
      - `consolidate_backups()`
      - `backup_cli()`
    - stouputils.collections module
      - `unique_list()`
    - stouputils.ctx module
      - `Muffle`
      - `LogToFile`
        - `LogToFile.common()`
    - stouputils.decorators module
      - `silent()`
      - `measure_time()`
      - `LogLevels`
        - `LogLevels.NONE`
        - `LogLevels.WARNING`
        - `LogLevels.WARNING_TRACEBACK`
        - `LogLevels.ERROR_TRACEBACK`
        - `LogLevels.RAISE_EXCEPTION`
      - `force_raise_exception`
      - `handle_error()`
      - `simple_cache()`
      - `deprecated()`
    - stouputils.io module
      - `replace_tilde()`
      - `clean_path()`
      - `super_open()`
      - `super_copy()`
      - `super_json_load()`
      - `super_json_dump()`
    - stouputils.parallel module
      - `multiprocessing()`
      - `multithreading()`
    - stouputils.print module
      - `remove_colors()`
      - `is_same_print()`
      - `info()`
      - `debug()`
      - `suggestion()`
      - `progress()`
      - `warning()`
      - `error()`
      - `whatisit()`
      - `breakpoint()`

# ⚡ Indices and Tables

- Index

- Module Index

- Search Page